@@ -1,6 +1,6 @@
 package Parse::Dia::SQL;
 
-# $Id: SQL.pm,v 1.37 2009/11/12 09:45:53 aff Exp $
+# $Id: SQL.pm,v 1.39 2009/12/18 07:04:04 aff Exp $
 
 =pod
 
@@ -188,7 +188,7 @@ use Parse::Dia::SQL::Output::Sas;
 use Parse::Dia::SQL::Output::Sybase;
 use Parse::Dia::SQL::Output::SQLite3;
 
-our $VERSION = '0.12_01';
+our $VERSION = '0.12_02';
 
 my $UML_ASSOCIATION  = 'UML - Association';
 my $UML_SMALLPACKAGE = 'UML - SmallPackage';
@@ -1675,6 +1675,9 @@ sub generate_one_to_any_association {
 				->warn( "Types of ($pkNames) don't match ($fkNames)" . " in $assocName");
 			return;
 		}
+	} else {
+		# Issue warning that ignore flag is set
+		$self->{log}->warn( "Ignoring type mismatch if any");
 	}
 
   # Use the user-supplied FK constraint name; otherwise generate one
